@@ -258,7 +258,7 @@ class TileLayer(RasterLayer):
     no_wrap = Bool(False).tag(sync=True, o=True)
     tms = Bool(False).tag(sync=True, o=True)
     show_loading = Bool(False).tag(sync=True)
-    loading = Bool(False).tag(sync=True)
+    loading = Bool(False, read_only=True).tag(sync=True)
 
     _load_callbacks = Instance(CallbackDispatcher, ())
 
@@ -914,10 +914,7 @@ class Map(DOMWidget, InteractMixin):
     dragging_style = InstanceDict(MapStyle).tag(sync=True, **widget_serialization)
 
     zoom_control = Bool(True)
-    zoom_control_instance = ZoomControl()
-
     attribution_control = Bool(True)
-    attribution_control_instance = AttributionControl(position='bottomright')
 
     @default('dragging_style')
     def _default_dragging_style(self):
@@ -951,29 +948,36 @@ class Map(DOMWidget, InteractMixin):
                                           (self.south, self.west)))
 
     def __init__(self, **kwargs):
+        self.zoom_control_instance = None
+        self.attribution_control_instance = None
+
         super(Map, self).__init__(**kwargs)
         self.on_msg(self._handle_leaflet_event)
 
         if self.zoom_control:
+            self.zoom_control_instance = ZoomControl()
             self.add_control(self.zoom_control_instance)
 
         if self.attribution_control:
+            self.attribution_control_instance = AttributionControl(position='bottomright')
             self.add_control(self.attribution_control_instance)
 
     @observe('zoom_control')
     def observe_zoom_control(self, change):
         if change['new']:
+            self.zoom_control_instance = ZoomControl()
             self.add_control(self.zoom_control_instance)
         else:
-            if self.zoom_control_instance in self.controls:
+            if self.zoom_control_instance is not None and self.zoom_control_instance in self.controls:
                 self.remove_control(self.zoom_control_instance)
 
     @observe('attribution_control')
     def observe_attribution_control(self, change):
         if change['new']:
+            self.attribution_control_instance = AttributionControl(position='bottomright')
             self.add_control(self.attribution_control_instance)
         else:
-            if self.attribution_control_instance in self.controls:
+            if self.attribution_control_instance is not None and self.attribution_control_instance in self.controls:
                 self.remove_control(self.attribution_control_instance)
 
     _layer_ids = List()
